==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-server/src/main/java/org/apache/hadoop/hbase/security/visibility/VisibilityExpEvaluator.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.security.visibility;

import java.io.IOException;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.classification.InterfaceStability;
import org.apache.hadoop.hbase.Cell;

/**
 * During the read (ie. get/Scan) the VisibilityController calls this interface for each of the
 * Cell. Depending on the evaluate() result, a cell can be either included or filtered out from the
 * read results.
 */
@InterfaceAudience.Public
@InterfaceStability.Evolving
public interface VisibilityExpEvaluator {

  /**
   * Evaluates whether the passed cell passes Scan/Get Authorization.
   * @param cell Cell under evaluation
   * @return true if this cell can be included in the Result. Else false.
   */
  boolean evaluate(Cell cell) throws IOException;
}

==> hbase-2.4.17-src.tar.gz: hbase-2.4.17/hbase-server/src/main/java/org/apache/hadoop/hbase/security/visibility/VisibilityExpEvaluator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.security.visibility;

import java.io.IOException;
import org.apache.hadoop.hbase.Cell;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * During the read (ie. get/Scan) the VisibilityController calls this interface for each of the
 * Cell. Depending on the evaluate() result, a cell can be either included or filtered out from the
 * read results.
 */
@InterfaceAudience.Public
public interface VisibilityExpEvaluator {

  /**
   * Evaluates whether the passed cell passes Scan/Get Authorization.
   * @param cell Cell under evaluation
   * @return true if this cell can be included in the Result. Else false.
   */
  boolean evaluate(Cell cell) throws IOException;
}
